@@ -6,9 +6,49 @@ from . import templates
 from . import filters
 from . import photoz
 
-from .version import __version__, __long_version__, __version_hash__
+from .version import __version__
 
-def symlink_eazy_inputs(path='$EAZYCODE', get_hdfn_test_catalog=False):
+try:
+    import dust_attenuation
+except ImportError:
+    print('Failed to `import dust_attenuation`')
+    print('Install my fork with $ pip install ' +
+          'git+https://github.com/gbrammer/dust_attenuation.git')
+
+try:
+    import dust_extinction
+except ImportError:
+    print('Failed to `import dust_extinction`')
+    print('Install my fork with $ pip install ' +
+          'git+https://github.com/gbrammer/dust_extinction.git')
+
+
+def fetch_eazy_photoz():
+    """
+    If necessary, clone the eazy-photoz repository to get templates and filters
+    """
+    module_path = os.path.dirname(__file__)
+    data_path = os.path.join(module_path, 'data/')
+    os.chdir(data_path)
+    
+    eazy_photoz = os.path.join(data_path, 'eazy-photoz')
+    git_url = 'https://github.com/gbrammer/eazy-photoz.git'
+    
+    if not os.path.exists(eazy_photoz):
+        os.system(f'git clone {git_url}')
+        print(f'cloning {git_url} to {data_path}')
+        
+    if not os.path.exists('filters'):
+        os.symlink(os.path.join('eazy-photoz','filters'), 'filters')
+
+    if not os.path.exists('templates'):
+        os.symlink(os.path.join('eazy-photoz','templates'), 'templates')
+
+    if not os.path.exists('hdfn_fs99'):
+        os.symlink(os.path.join('eazy-photoz','inputs'), 'hdfn_fs99')
+
+
+def symlink_eazy_inputs(path='$EAZYCODE', get_hdfn_test_catalog=False, copy=False):
     """
     Make symbolic links to EAZY inputs
     
@@ -30,6 +70,10 @@ def symlink_eazy_inputs(path='$EAZYCODE', get_hdfn_test_catalog=False):
         to point to it (e.g, 'EAZYCODE'), which you then pass as the `path`
         argument.
     
+    copy : bool
+        Copy ``templates`` directory and ``FILTER.RES.latest`` file, rather 
+        than symlink
+        
     Returns
     -------
     Symbolic links to the `FILTER.RES.latest` file and `templates` 
@@ -43,24 +87,39 @@ def symlink_eazy_inputs(path='$EAZYCODE', get_hdfn_test_catalog=False):
     if path is None:
         # Use the code attached to the repository
         path = os.path.join(os.path.dirname(__file__), 'data/')
-        
+        if not os.path.exists(os.path.join(path, 'templates')):
+            fetch_eazy_photoz()
+            
     if not os.path.exists(path):
         print('Couldn\'t find path {0}'.format(path))
         return False
     
     # Templates directory
     if os.path.exists('./templates'):
-        os.remove('./templates')
+        try:
+            os.remove('./templates')
+        except PermissionError:
+            os.system('rm -rf templates')
+    
+    t_path = os.path.join(path, 'templates')
+    if copy:
+        os.system('cp -R {0} .'.format(t_path))
+    else:
+        os.symlink(t_path, './templates')
         
-    os.symlink(os.path.join(path, 'templates'), './templates')
-    print('{0} -> {1}'.format(os.path.join(path, 'templates'), './templates'))
+    print('{0} -> {1}'.format(t_path, './templates'))
     
     # Filter file
     if os.path.exists('./FILTER.RES.latest'):
         os.remove('./FILTER.RES.latest')
     
-    os.symlink(os.path.join(path, 'filters/FILTER.RES.latest'), './FILTER.RES.latest')
-    print('{0} -> {1}'.format(os.path.join(path, 'filters/FILTER.RES.latest'), './FILTER.RES.latest'))
+    res_path = os.path.join(path, 'filters/FILTER.RES.latest')
+    if copy:
+        os.system(f'cp {0} .'.format(res_path))
+    else:
+        os.symlink(res_path, './FILTER.RES.latest')
+        
+    print('{0} -> {1}'.format(res_path, './FILTER.RES.latest'))
     
     if get_hdfn_test_catalog:
         for cat_path in ['inputs', 'hdfn_fs99']:
@@ -70,7 +129,8 @@ def symlink_eazy_inputs(path='$EAZYCODE', get_hdfn_test_catalog=False):
                 for file in [parent, translate]:
                     os.symlink(file, os.path.basename(file))
                     print('{0} -> {1}'.format(file, os.path.basename(file)))
-                    
+
+
 def get_test_catalog(path=None, path_is_env=True):
     """
     Make symbolic links to EAZY inputs
